@@ -1,21 +1,11 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2000 Kurt Granroth <granroth@kde.org>
-   Copyright (C) 2006 Hamish Rodda <rodda@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Kurt Granroth <granroth@kde.org>
+    SPDX-FileCopyrightText: 2006 Hamish Rodda <rodda@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
+
 #ifndef KEDITTOOLBARP_H
 #define KEDITTOOLBARP_H
 
@@ -29,7 +19,6 @@ class QCheckBox;
 
 namespace KDEPrivate
 {
-
 class ToolBarItem;
 class KEditToolBarWidgetPrivate;
 
@@ -37,7 +26,7 @@ class ToolBarListWidget : public QListWidget
 {
     Q_OBJECT
 public:
-    ToolBarListWidget(QWidget *parent = nullptr);
+    explicit ToolBarListWidget(QWidget *parent = nullptr);
 
     void makeVisible(QListWidgetItem *item)
     {
@@ -136,8 +125,7 @@ public:
      * @param collection The collection of actions to work on
      * @param parent This widget's parent
      */
-    explicit KEditToolBarWidget(KActionCollection *collection,
-                                QWidget *parent = nullptr);
+    explicit KEditToolBarWidget(KActionCollection *collection, QWidget *parent = nullptr);
 
     /**
      * Main constructor.
@@ -186,9 +174,7 @@ public:
      *
      * @see KEditToolBar
      */
-    void load(const QString &resourceFile,
-              bool global = true,
-              const QString &defaultToolBar = QString());
+    void load(const QString &resourceFile, bool global = true, const QString &defaultToolBar = QString());
 
     /**
      * Loads the toolbar configuration into the widget. Should be called before being shown.
@@ -203,8 +189,7 @@ public:
      *
      * @see KEditToolBar
      */
-    void load(KXMLGUIFactory *factory,
-              const QString &defaultToolBar = QString());
+    void load(KXMLGUIFactory *factory, const QString &defaultToolBar = QString());
 
     /**
      * @internal Reimplemented for internal purposes.
@@ -231,22 +216,6 @@ Q_SIGNALS:
      */
     void enableOk(bool);
 
-private:
-    Q_PRIVATE_SLOT(d, void slotToolBarSelected(int index))
-
-    Q_PRIVATE_SLOT(d, void slotInactiveSelectionChanged())
-    Q_PRIVATE_SLOT(d, void slotActiveSelectionChanged())
-
-    Q_PRIVATE_SLOT(d, void slotInsertButton())
-    Q_PRIVATE_SLOT(d, void slotRemoveButton())
-    Q_PRIVATE_SLOT(d, void slotUpButton())
-    Q_PRIVATE_SLOT(d, void slotDownButton())
-
-    Q_PRIVATE_SLOT(d, void slotChangeIcon())
-    Q_PRIVATE_SLOT(d, void slotChangeIconText())
-
-    Q_PRIVATE_SLOT(d, void slotDropped(ToolBarListWidget *, int, ToolBarItem *, bool))
-
 private:
     friend class KEditToolBarWidgetPrivate;
     KEditToolBarWidgetPrivate *const d;
