@@ -1,33 +1,21 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2001 Simon Hausmann <hausmann@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2001 Simon Hausmann <hausmann@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kxmlguifactory_p.h"
 
-#include "kxmlguiclient.h"
-#include "kxmlguibuilder.h"
 #include "ktoolbar.h"
+#include "kxmlguibuilder.h"
+#include "kxmlguiclient.h"
 
+#include <QVector>
 #include <QWidget>
-#include <QDebug>
 
 #include "debug.h"
-#include <assert.h>
+#include <cassert>
 
 using namespace KXMLGUI;
 
@@ -38,25 +26,38 @@ void ActionList::plug(QWidget *container, int index) const
     if ((index < 0) || (index > container->actions().count())) {
         qCWarning(DEBUG_KXMLGUI) << "Index " << index << " is not within range (0 - " << container->actions().count() << ")";
     } else if (index != container->actions().count()) {
-        before = container->actions().at(index);    // Insert before indexed action.
+        before = container->actions().at(index); // Insert before indexed action.
     }
 
-    Q_FOREACH (QAction *action, *this) {
+    for (QAction *action : *this) {
         container->insertAction(before, action);
         // before = action; // BUG FIX: do not insert actions in reverse order.
     }
 }
 
-ContainerNode::ContainerNode(QWidget *_container, const QString &_tagName,
-                             const QString &_name, ContainerNode *_parent,
-                             KXMLGUIClient *_client, KXMLGUIBuilder *_builder,
-                             QAction *_containerAction, const QString &_mergingName,
-                             const QString &_groupName, const QStringList &customTags,
+ContainerNode::ContainerNode(QWidget *_container,
+                             const QString &_tagName,
+                             const QString &_name,
+                             ContainerNode *_parent,
+                             KXMLGUIClient *_client,
+                             KXMLGUIBuilder *_builder,
+                             QAction *_containerAction,
+                             const QString &_mergingName,
+                             const QString &_groupName,
+                             const QStringList &customTags,
                              const QStringList &containerTags)
-    : parent(_parent), client(_client), builder(_builder),
-      builderCustomTags(customTags), builderContainerTags(containerTags),
-      container(_container), containerAction(_containerAction), tagName(_tagName), name(_name),
-      groupName(_groupName), index(0), mergingName(_mergingName)
+    : parent(_parent)
+    , client(_client)
+    , builder(_builder)
+    , builderCustomTags(customTags)
+    , builderContainerTags(containerTags)
+    , container(_container)
+    , containerAction(_containerAction)
+    , tagName(_tagName)
+    , name(_name)
+    , groupName(_groupName)
+    , index(0)
+    , mergingName(_mergingName)
 {
     if (parent) {
         parent->children.append(this);
@@ -88,8 +89,9 @@ void ContainerNode::deleteChild(ContainerNode *child)
  */
 MergingIndexList::iterator ContainerNode::findIndex(const QString &name)
 {
-    return std::find_if(mergingIndices.begin(), mergingIndices.end(),
-                        [&name](const MergingIndex &idx) { return idx.mergingName == name; });
+    return std::find_if(mergingIndices.begin(), mergingIndices.end(), [&name](const MergingIndex &idx) {
+        return idx.mergingName == name;
+    });
 }
 
 /*
@@ -99,12 +101,11 @@ MergingIndexList::iterator ContainerNode::findIndex(const QString &name)
  */
 ContainerNode *ContainerNode::findContainer(const QString &_name, bool tag)
 {
-    if ((tag && tagName == _name) ||
-            (!tag && name == _name)) {
+    if ((tag && tagName == _name) || (!tag && name == _name)) {
         return this;
     }
 
-    Q_FOREACH (ContainerNode *child, children) {
+    for (ContainerNode *child : qAsConst(children)) {
         ContainerNode *res = child->findContainer(_name, tag);
         if (res) {
             return res;
@@ -119,17 +120,14 @@ ContainerNode *ContainerNode::findContainer(const QString &_name, bool tag)
  * leaves out container widgets specified in the exludeList . Also ensures that the containers
  * belongs to currClient.
  */
-ContainerNode *ContainerNode::findContainer(const QString &name, const QString &tagName,
-        const QList<QWidget *> *excludeList,
-        KXMLGUIClient * /*currClient*/)
+ContainerNode *ContainerNode::findContainer(const QString &name, const QString &tagName, const QList<QWidget *> *excludeList, KXMLGUIClient * /*currClient*/)
 {
     ContainerNode *res = nullptr;
     ContainerNodeList::ConstIterator nIt = children.constBegin();
 
     if (!name.isEmpty()) {
         for (; nIt != children.constEnd(); ++nIt)
-            if ((*nIt)->name == name &&
-                    !excludeList->contains((*nIt)->container)) {
+            if ((*nIt)->name == name && !excludeList->contains((*nIt)->container)) {
                 res = *nIt;
                 break;
             }
@@ -139,24 +137,23 @@ ContainerNode *ContainerNode::findContainer(const QString &name, const QString &
 
     if (!tagName.isEmpty())
         for (; nIt != children.constEnd(); ++nIt) {
-            if ((*nIt)->tagName == tagName &&
-                    !excludeList->contains((*nIt)->container)
-                    /*
-                     * It is a bad idea to also compare the client, because
-                     * we don't want to do so in situations like these:
-                     *
-                     * <MenuBar>
-                     *   <Menu>
-                     *     ...
-                     *
-                     * other client:
-                     * <MenuBar>
-                     *   <Menu>
-                     *    ...
-                     *
-                    && (*nIt)->client == currClient )
-                    */
-               ) {
+            if ((*nIt)->tagName == tagName && !excludeList->contains((*nIt)->container)
+                /*
+                 * It is a bad idea to also compare the client, because
+                 * we don't want to do so in situations like these:
+                 *
+                 * <MenuBar>
+                 *   <Menu>
+                 *     ...
+                 *
+                 * other client:
+                 * <MenuBar>
+                 *   <Menu>
+                 *    ...
+                 *
+                && (*nIt)->client == currClient )
+                */
+            ) {
                 res = *nIt;
                 break;
             }
@@ -165,12 +162,11 @@ ContainerNode *ContainerNode::findContainer(const QString &name, const QString &
     return res;
 }
 
-ContainerClient *ContainerNode::findChildContainerClient(KXMLGUIClient *currentGUIClient,
-        const QString &groupName,
-        const MergingIndexList::iterator &mergingIdx)
+ContainerClient *
+ContainerNode::findChildContainerClient(KXMLGUIClient *currentGUIClient, const QString &groupName, const MergingIndexList::iterator &mergingIdx)
 {
     if (!clients.isEmpty()) {
-        Q_FOREACH (ContainerClient *client, clients)
+        for (ContainerClient *client : qAsConst(clients)) {
             if (client->client == currentGUIClient) {
                 if (groupName.isEmpty()) {
                     return client;
@@ -180,6 +176,7 @@ ContainerClient *ContainerNode::findChildContainerClient(KXMLGUIClient *currentG
                     return client;
                 }
             }
+        }
     }
 
     ContainerClient *client = new ContainerClient;
@@ -203,14 +200,14 @@ void ContainerNode::plugActionList(BuildState &state)
         plugActionList(state, mIt);
     }
 
-    Q_FOREACH (ContainerNode *child, children) {
+    for (ContainerNode *child : qAsConst(children)) {
         child->plugActionList(state);
     }
 }
 
 void ContainerNode::plugActionList(BuildState &state, const MergingIndexList::iterator &mergingIdxIt)
 {
-    static const QString &tagActionList = QLatin1String("actionlist");
+    const QLatin1String tagActionList("actionlist");
 
     const MergingIndex &mergingIdx = *mergingIdxIt;
     if (mergingIdx.clientName != state.clientName) {
@@ -219,14 +216,12 @@ void ContainerNode::plugActionList(BuildState &state, const MergingIndexList::it
     if (!mergingIdx.mergingName.startsWith(tagActionList)) {
         return;
     }
-    const QString k = mergingIdx.mergingName.mid(tagActionList.length());
+    const QString k = mergingIdx.mergingName.mid(tagActionList.size());
     if (k != state.actionListName) {
         return;
     }
 
-    ContainerClient *client = findChildContainerClient(state.guiClient,
-                              QString(),
-                              mergingIndices.end());
+    ContainerClient *client = findChildContainerClient(state.guiClient, QString(), mergingIndices.end());
 
     client->actionLists.insert(k, state.actionList);
 
@@ -243,14 +238,14 @@ void ContainerNode::unplugActionList(BuildState &state)
         unplugActionList(state, mIt);
     }
 
-    Q_FOREACH (ContainerNode *child, children) {
+    for (ContainerNode *child : qAsConst(children)) {
         child->unplugActionList(state);
     }
 }
 
 void ContainerNode::unplugActionList(BuildState &state, const MergingIndexList::iterator &mergingIdxIt)
 {
-    static const QString &tagActionList = QStringLiteral("actionlist");
+    const QLatin1String tagActionList("actionlist");
 
     MergingIndex mergingIdx = *mergingIdxIt;
 
@@ -260,7 +255,7 @@ void ContainerNode::unplugActionList(BuildState &state, const MergingIndexList::
         return;
     }
 
-    k = k.mid(tagActionList.length());
+    k.remove(0, tagActionList.size());
 
     if (mergingIdx.clientName != state.clientName) {
         return;
@@ -270,9 +265,7 @@ void ContainerNode::unplugActionList(BuildState &state, const MergingIndexList::
         return;
     }
 
-    ContainerClient *client = findChildContainerClient(state.guiClient,
-                              QString(),
-                              mergingIndices.end());
+    ContainerClient *client = findChildContainerClient(state.guiClient, QString(), mergingIndices.end());
 
     ActionListMap::Iterator lIt(client->actionLists.find(k));
     if (lIt == client->actionLists.end()) {
@@ -284,9 +277,7 @@ void ContainerNode::unplugActionList(BuildState &state, const MergingIndexList::
     client->actionLists.erase(lIt);
 }
 
-void ContainerNode::adjustMergingIndices(int offset,
-                                         const MergingIndexList::iterator &it,
-                                         const QString &currentClientName)
+void ContainerNode::adjustMergingIndices(int offset, const MergingIndexList::iterator &it, const QString &currentClientName)
 {
     MergingIndexList::iterator mergingIt = it;
     MergingIndexList::iterator mergingEnd = mergingIndices.end();
@@ -300,7 +291,9 @@ void ContainerNode::adjustMergingIndices(int offset,
     index += offset;
 }
 
-bool ContainerNode::destruct(QDomElement element, BuildState &state)   //krazy:exclude=passbyvalue (this is correct QDom usage, and a ref wouldn't allow passing doc.documentElement() as argument)
+bool ContainerNode::destruct(
+    QDomElement element,
+    BuildState &state) // krazy:exclude=passbyvalue (this is correct QDom usage, and a ref wouldn't allow passing doc.documentElement() as argument)
 {
     destructChildren(element, state);
 
@@ -314,8 +307,7 @@ bool ContainerNode::destruct(QDomElement element, BuildState &state)   //krazy:e
         }
 
     // ### check for merging index count, too?
-    if (clients.isEmpty() && children.isEmpty() && container &&
-            client == state.guiClient) {
+    if (clients.isEmpty() && children.isEmpty() && container && client == state.guiClient) {
         QWidget *parentContainer = nullptr;
         if (parent && parent->container) {
             parentContainer = parent->container;
@@ -351,15 +343,13 @@ void ContainerNode::destructChildren(const QDomElement &element, BuildState &sta
     }
 }
 
-QDomElement ContainerNode::findElementForChild(const QDomElement &baseElement,
-        ContainerNode *childNode)
+QDomElement ContainerNode::findElementForChild(const QDomElement &baseElement, ContainerNode *childNode)
 {
     // ### slow
-    for (QDomNode n = baseElement.firstChild(); !n.isNull();
-            n = n.nextSibling()) {
+    for (QDomNode n = baseElement.firstChild(); !n.isNull(); n = n.nextSibling()) {
         QDomElement e = n.toElement();
-        if (e.tagName().toLower() == childNode->tagName &&
-                e.attribute(QStringLiteral("name")) == childNode->name) {
+        if (e.tagName().toLower() == childNode->tagName //
+            && e.attribute(QStringLiteral("name")) == childNode->name) {
             return e;
         }
     }
@@ -375,8 +365,8 @@ void ContainerNode::unplugActions(BuildState &state)
 
     QMutableListIterator<ContainerClient *> clientIt(clients);
     while (clientIt.hasNext()) {
-        //only unplug the actions of the client we want to remove, as the container might be owned
-        //by a different client
+        // only unplug the actions of the client we want to remove, as the container might be owned
+        // by a different client
         ContainerClient *cClient = clientIt.next();
         if (cClient->client == state.guiClient) {
             unplugClient(cClient);
@@ -417,16 +407,14 @@ void ContainerNode::unplugClient(ContainerClient *client)
 
     // unplug all actionslists
 
-    ActionListMap::ConstIterator alIt = client->actionLists.constBegin();
-    ActionListMap::ConstIterator alEnd = client->actionLists.constEnd();
-    for (; alIt != alEnd; ++alIt) {
-        removeActions(alIt.value());
+    for (const auto &actionList : qAsConst(client->actionLists)) {
+        removeActions(actionList);
     }
 }
 
 void ContainerNode::reset()
 {
-    Q_FOREACH (ContainerNode *child, children) {
+    for (ContainerNode *child : qAsConst(children)) {
         child->reset();
     }
 
@@ -435,10 +423,7 @@ void ContainerNode::reset()
     }
 }
 
-int ContainerNode::calcMergingIndex(const QString &mergingName,
-                                    MergingIndexList::iterator &it,
-                                    BuildState &state,
-                                    bool ignoreDefaultMergingIndex)
+int ContainerNode::calcMergingIndex(const QString &mergingName, MergingIndexList::iterator &it, BuildState &state, bool ignoreDefaultMergingIndex)
 {
     const MergingIndexList::iterator mergingIt = findIndex(mergingName.isEmpty() ? state.clientName : mergingName);
     const MergingIndexList::iterator mergingEnd = mergingIndices.end();
@@ -459,9 +444,10 @@ int ContainerNode::calcMergingIndex(const QString &mergingName,
 
 void ContainerNode::dump(int offset)
 {
-    QString indent; indent.fill(QLatin1Char(' '), offset);
+    QString indent;
+    indent.fill(QLatin1Char(' '), offset);
     qCDebug(DEBUG_KXMLGUI) << qPrintable(indent) << name << tagName << groupName << mergingName << mergingIndices;
-    Q_FOREACH (ContainerNode *child, children) {
+    for (ContainerNode *child : qAsConst(children)) {
         child->dump(offset + 2);
     }
 }
@@ -494,8 +480,10 @@ int BuildHelper::calcMergingIndex(const QDomElement &element, MergingIndexList::
 }
 
 BuildHelper::BuildHelper(BuildState &state, ContainerNode *node)
-    : containerClient(nullptr), ignoreDefaultMergingIndex(false), m_state(state),
-      parentNode(node)
+    : containerClient(nullptr)
+    , ignoreDefaultMergingIndex(false)
+    , m_state(state)
+    , parentNode(node)
 {
     // create a list of supported container and custom tags
     customTags = m_state.builderCustomTags;
@@ -512,8 +500,7 @@ BuildHelper::BuildHelper(BuildState &state, ContainerNode *node)
     }
 
     m_state.currentDefaultMergingIt = parentNode->findIndex(QStringLiteral("<default>"));
-    parentNode->calcMergingIndex(QString(), m_state.currentClientMergingIt,
-                                 m_state, /*ignoreDefaultMergingIndex*/ false);
+    parentNode->calcMergingIndex(QString(), m_state.currentClientMergingIt, m_state, /*ignoreDefaultMergingIndex*/ false);
 }
 
 void BuildHelper::build(const QDomElement &element)
@@ -532,16 +519,15 @@ void BuildHelper::processElement(const QDomElement &e)
     QString tag(e.tagName().toLower());
     QString currName(e.attribute(QStringLiteral("name")));
 
-    bool isActionTag = (tag == QStringLiteral("action"));
+    const bool isActionTag = (tag == QLatin1String("action"));
 
     if (isActionTag || customTags.indexOf(tag) != -1) {
         processActionOrCustomElement(e, isActionTag);
     } else if (containerTags.indexOf(tag) != -1) {
         processContainerElement(e, tag, currName);
-    } else if (tag == QStringLiteral("merge") || tag == QLatin1String("definegroup")
-               || tag == QStringLiteral("actionlist")) {
+    } else if (tag == QLatin1String("merge") || tag == QLatin1String("definegroup") || tag == QLatin1String("actionlist")) {
         processMergeElement(tag, currName, e);
-    } else if (tag == QStringLiteral("state")) {
+    } else if (tag == QLatin1String("state")) {
         processStateElement(e);
     }
 }
@@ -583,7 +569,7 @@ bool BuildHelper::processActionElement(const QDomElement &e, int idx)
         return false;
     }
 
-    //qCDebug(DEBUG_KXMLGUI) << e.attribute(QStringLiteral("name")) << "->" << action << "inserting at idx=" << idx;
+    // qCDebug(DEBUG_KXMLGUI) << e.attribute(QStringLiteral("name")) << "->" << action << "inserting at idx=" << idx;
 
     QAction *before = nullptr;
     if (idx >= 0 && idx < parentNode->container->actions().count()) {
@@ -627,16 +613,16 @@ void BuildHelper::processStateElement(const QDomElement &element)
 
         QString tagName = e.tagName().toLower();
 
-        if (tagName != QStringLiteral("enable") && tagName != QLatin1String("disable")) {
+        if (tagName != QLatin1String("enable") && tagName != QLatin1String("disable")) {
             continue;
         }
 
-        bool processingActionsToEnable = (tagName == QStringLiteral("enable"));
+        const bool processingActionsToEnable = (tagName == QLatin1String("enable"));
 
         // process action names
         for (QDomNode n2 = n.firstChild(); !n2.isNull(); n2 = n2.nextSibling()) {
             QDomElement actionEl = n2.toElement();
-            if (actionEl.tagName().toLower() != QStringLiteral("action")) {
+            if (actionEl.tagName().compare(QLatin1String("action"), Qt::CaseInsensitive) != 0) {
                 continue;
             }
 
@@ -650,7 +636,6 @@ void BuildHelper::processStateElement(const QDomElement &element)
             } else {
                 m_state.guiClient->addStateActionDisabled(stateName, actionName);
             }
-
         }
     }
 }
@@ -665,25 +650,25 @@ void BuildHelper::processMergeElement(const QString &tag, const QString &name, c
     QString mergingName(name);
     if (mergingName.isEmpty()) {
         if (tag == tagDefineGroup) {
-            qCritical() << "cannot define group without name!" << endl;
+            qCCritical(DEBUG_KXMLGUI) << "cannot define group without name!";
             return;
         }
         if (tag == tagActionList) {
-            qCritical() << "cannot define actionlist without name!" << endl;
+            qCCritical(DEBUG_KXMLGUI) << "cannot define actionlist without name!";
             return;
         }
         mergingName = defaultMergingName;
     }
 
     if (tag == tagDefineGroup) {
-        mergingName.prepend(attrGroup);    //avoid possible name clashes by prepending
-                                           // "group" to group definitions
+        mergingName.prepend(attrGroup); // avoid possible name clashes by prepending
+                                        // "group" to group definitions
     } else if (tag == tagActionList) {
         mergingName.prepend(tagActionList);
     }
 
     if (parentNode->findIndex(mergingName) != parentNode->mergingIndices.end()) {
-        return;    //do not allow the redefinition of merging indices!
+        return; // do not allow the redefinition of merging indices!
     }
 
     MergingIndexList::iterator mIt(parentNode->mergingIndices.end());
@@ -716,16 +701,12 @@ void BuildHelper::processMergeElement(const QString &tag, const QString &name, c
     // re-calculate the running default and client merging indices
     // (especially important in case the QList data got reallocated due to growing!)
     m_state.currentDefaultMergingIt = parentNode->findIndex(defaultMergingName);
-    parentNode->calcMergingIndex(QString(), m_state.currentClientMergingIt,
-                                 m_state, ignoreDefaultMergingIndex);
+    parentNode->calcMergingIndex(QString(), m_state.currentClientMergingIt, m_state, ignoreDefaultMergingIndex);
 }
 
-void BuildHelper::processContainerElement(const QDomElement &e, const QString &tag,
-        const QString &name)
+void BuildHelper::processContainerElement(const QDomElement &e, const QString &tag, const QString &name)
 {
-    ContainerNode *containerNode = parentNode->findContainer(name, tag,
-                                   &containerList,
-                                   m_state.guiClient);
+    ContainerNode *containerNode = parentNode->findContainer(name, tag, &containerList, m_state.guiClient);
 
     if (!containerNode) {
         MergingIndexList::iterator it(m_state.currentClientMergingIt);
@@ -747,9 +728,12 @@ void BuildHelper::processContainerElement(const QDomElement &e, const QString &t
         parentNode->adjustMergingIndices(1, it, m_state.clientName);
 
         // Check that the container widget is not already in parentNode.
-        Q_ASSERT(std::find_if(parentNode->children.constBegin(), parentNode->children.constEnd(),
-                              [container](ContainerNode *child) { return child->container == container; })
-                == parentNode->children.constEnd());
+        Q_ASSERT(std::find_if(parentNode->children.constBegin(),
+                              parentNode->children.constEnd(),
+                              [container](ContainerNode *child) {
+                                  return child->container == container;
+                              })
+                 == parentNode->children.constEnd());
 
         containerList.append(container);
 
@@ -765,11 +749,9 @@ void BuildHelper::processContainerElement(const QDomElement &e, const QString &t
             conTags = m_state.clientBuilderContainerTags;
         }
 
-        containerNode = new ContainerNode(container, tag, name, parentNode,
-                                          m_state.guiClient, builder, containerAction,
-                                          mergingName, group, cusTags, conTags);
+        containerNode = new ContainerNode(container, tag, name, parentNode, m_state.guiClient, builder, containerAction, mergingName, group, cusTags, conTags);
     } else {
-        if (tag == QStringLiteral("toolbar")) {
+        if (tag == QLatin1String("toolbar")) {
             KToolBar *bar = qobject_cast<KToolBar *>(containerNode->container);
             if (bar) {
                 if (m_state.guiClient && !m_state.guiClient->xmlFile().isEmpty()) {
@@ -785,13 +767,10 @@ void BuildHelper::processContainerElement(const QDomElement &e, const QString &t
 
     // and re-calculate running values, for better performance
     m_state.currentDefaultMergingIt = parentNode->findIndex(QStringLiteral("<default>"));
-    parentNode->calcMergingIndex(QString(), m_state.currentClientMergingIt,
-                                 m_state, ignoreDefaultMergingIndex);
+    parentNode->calcMergingIndex(QString(), m_state.currentClientMergingIt, m_state, ignoreDefaultMergingIndex);
 }
 
-QWidget *BuildHelper::createContainer(QWidget *parent, int index,
-                                      const QDomElement &element, QAction *&containerAction,
-                                      KXMLGUIBuilder **builder)
+QWidget *BuildHelper::createContainer(QWidget *parent, int index, const QDomElement &element, QAction *&containerAction, KXMLGUIBuilder **builder)
 {
     QWidget *res = nullptr;
 
@@ -830,7 +809,8 @@ void BuildState::reset()
     currentDefaultMergingIt = currentClientMergingIt = MergingIndexList::iterator();
 }
 
-QDebug operator<<(QDebug stream, const MergingIndex &mi) {
+QDebug operator<<(QDebug stream, const MergingIndex &mi)
+{
     QDebugStateSaver saver(stream);
     stream.nospace() << "clientName=" << mi.clientName << " mergingName=" << mi.mergingName << " value=" << mi.value;
     return stream;
