@@ -14,9 +14,9 @@
 #ifndef KXMLGUIWINDOW_H
 #define KXMLGUIWINDOW_H
 
-#include "kxmlguiclient.h"
-#include "kxmlguibuilder.h"
 #include "kmainwindow.h"
+#include "kxmlguibuilder.h"
+#include "kxmlguiclient.h"
 
 class KMenu;
 class KXMLGUIFactory;
@@ -38,13 +38,13 @@ class KXmlGuiWindowPrivate;
  * for essential information on the XML file format and usage of this class.
  *
  * @see KMainWindow
- * @author Reginald Stadlbauer (reggie@kde.org) Stephan Kulow (coolo@kde.org), Matthias Ettrich (ettrich@kde.org), Chris Schlaeger (cs@kde.org), Sven Radej (radej@kde.org). Maintained by Sven Radej (radej@kde.org)
+ * @author Reginald Stadlbauer (reggie@kde.org) Stephan Kulow (coolo@kde.org), Matthias Ettrich (ettrich@kde.org), Chris Schlaeger (cs@kde.org), Sven Radej
+ (radej@kde.org). Maintained by Sven Radej (radej@kde.org)
 
  */
 
 class KXMLGUI_EXPORT KXmlGuiWindow : public KMainWindow, public KXMLGUIBuilder, virtual public KXMLGUIClient
 {
-    XMLGUI_DECLARE_PRIVATE(KXmlGuiWindow)
     Q_OBJECT
     Q_PROPERTY(bool hasMenuBar READ hasMenuBar)
     Q_PROPERTY(bool autoSaveSettings READ autoSaveSettings)
@@ -220,7 +220,7 @@ public:
          * All the above option
          * (this is the default)
          */
-        Default = ToolBar | Keys | StatusBar | Save | Create
+        Default = ToolBar | Keys | StatusBar | Save | Create,
     };
     Q_FLAG(StandardWindowOption)
     /**
@@ -313,8 +313,7 @@ public Q_SLOTS:
      * can "reverse" the state (disable the actions which should be
      * enabled, and vice-versa) if specified.
      */
-    void slotStateChanged(const QString &newstate,
-                          bool reverse);
+    void slotStateChanged(const QString &newstate, bool reverse);
 
 protected:
     /**
@@ -339,7 +338,7 @@ protected Q_SLOTS:
     virtual void saveNewToolbarConfig();
 
 private:
-    Q_PRIVATE_SLOT(k_func(), void _k_slotFactoryMakingChanges(bool))
+    Q_DECLARE_PRIVATE_D(k_ptr, KXmlGuiWindow)
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KXmlGuiWindow::StandardWindowOptions)
